# pwiki
[![Build Status](https://github.com/fastily/pwiki/workflows/build/badge.svg)](#)
[![Python 3.9+](https://upload.wikimedia.org/wikipedia/commons/4/4f/Blue_Python_3.9%2B_Shield_Badge.svg)](https://www.python.org)
[![MediaWiki 1.35+](https://upload.wikimedia.org/wikipedia/commons/b/b3/Blue_MediaWiki_1.35%2B_Shield_Badge.svg)](https://www.mediawiki.org/wiki/MediaWiki)
[![License: GPL v3](https://upload.wikimedia.org/wikipedia/commons/8/86/GPL_v3_Blue_Badge.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)

pwiki is a Python library for effortlessly interacting with Wikipedia/MediaWiki

## Install
```bash
pip install pwiki
```

## Resources
* [API Docs](https://fastily.github.io/pwiki/)